@@ -13,8 +13,17 @@ function clone-fetch-hadoop() {
   curr_ref=$(git rev-parse HEAD)
   origin_trunk_curr_ref=$(git rev-parse $TRUNK_BRANCH)
   if [ "$curr_ref" != "$origin_trunk_curr_ref" ]; then
-    echo "Resetting to $TRUNK_BRANCH..."
-    git reset --hard $TRUNK_BRANCH
+    if [ -z ${TEST_EXEC_MODE+x} ]; then
+      echo "Test exec mode not set, resetting to $TRUNK_BRANCH with git reset --hard..."
+      git reset --hard $TRUNK_BRANCH
+    else
+      echo "Test exec mode set, resetting to $TRUNK_BRANCH with git reset..."
+      if [[ -z $(git status -s) ]]; then
+        echo "There are unstaged changes in repo `pwd`. Exiting"
+        return 1
+      fi
+      git reset $TRUNK_BRANCH
+    fi
   fi
 
   set +e
